@@ -76,9 +76,12 @@ struct _GcmCalibrateArgyllPrivate
 	glong				 vte_previous_row;
 	glong				 vte_previous_col;
 	gboolean			 already_on_window;
+	gboolean			 done_calibrate;
 	GcmCalibrateArgyllState		 state;
 	GcmPrint			*print;
 	const gchar			*argyllcms_ok;
+	guint				 terminal_child_exited_id;
+	guint				 terminal_cursor_moved_id;
 };
 
 enum {
@@ -355,7 +358,9 @@ static gboolean
 gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar **argv, GError **error)
 {
 	gboolean ret = FALSE;
+#if VTE_CHECK_VERSION(0,25,0)
 	const gchar *envp[] = { "ARGYLL_NOT_INTERACTIVE", NULL };
+#endif
 	const gchar *working_directory;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
@@ -365,6 +370,8 @@ gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar *
 
 	/* try to run */
 	working_directory = gcm_calibrate_get_working_path (GCM_CALIBRATE (calibrate_argyll));
+
+#if VTE_CHECK_VERSION(0,25,0)
 	ret = vte_terminal_fork_command_full (VTE_TERMINAL(priv->terminal),
 					      VTE_PTY_DEFAULT,
 					      working_directory,
@@ -372,6 +379,19 @@ gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar *
 					      G_SPAWN_FILE_AND_ARGV_ZERO,
 					      NULL, NULL,
 					      &priv->child_pid, error);
+#else
+	priv->child_pid = vte_terminal_fork_command (VTE_TERMINAL(priv->terminal),
+						     argv[0], &argv[1], NULL,
+						     working_directory,
+						     FALSE, FALSE, FALSE);
+	ret = (priv->child_pid > 0);
+	if (!ret) {
+		g_set_error (error,
+			     GCM_CALIBRATE_ERROR,
+			     GCM_CALIBRATE_ERROR_USER_ABORT,
+			     "failed to spawn %s", argv[0]);
+	}
+#endif
 	if (!ret)
 		goto out;
 
@@ -444,7 +464,8 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
 	g_ptr_array_add (array, g_strdup ("-ql"));
 	g_ptr_array_add (array, g_strdup ("-m"));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", priv->display));
@@ -534,7 +555,10 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
+	if (priv->done_calibrate)
+		g_ptr_array_add (array, g_strdup ("-N"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
@@ -619,7 +643,8 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
 	if (device_kind == GCM_DEVICE_KIND_PRINTER) {
 		/* print RGB */
 		g_ptr_array_add (array, g_strdup ("-d2"));
@@ -723,7 +748,8 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", priv->display));
 	g_ptr_array_add (array, g_strdup_printf ("-y%c", kind));
 	g_ptr_array_add (array, g_strdup ("-k"));
@@ -833,7 +859,8 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
 	g_ptr_array_add (array, g_strdup_printf ("-A%s", manufacturer));
 	g_ptr_array_add (array, g_strdup_printf ("-M%s", model));
 	g_ptr_array_add (array, g_strdup_printf ("-D%s", description_new));
@@ -1053,7 +1080,8 @@ gcm_calibrate_argyll_device_measure (GcmCalibrateArgyll *calibrate_argyll, GErro
 	filename = g_strdup_printf ("%s.tif", basename);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
 	g_ptr_array_add (array, g_strdup ("-p"));
 	g_ptr_array_add (array, g_strdup ("-a"));
 	g_ptr_array_add (array, g_strdup (filename));
@@ -1166,7 +1194,8 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
-	g_ptr_array_add (array, g_strdup ("-v9"));
+	g_ptr_array_add (array, g_strdup (command));
+	g_ptr_array_add (array, g_strdup ("-v"));
 	g_ptr_array_add (array, g_strdup_printf ("-A%s", manufacturer));
 	g_ptr_array_add (array, g_strdup_printf ("-M%s", model));
 	g_ptr_array_add (array, g_strdup_printf ("-D%s", description_tmp));
@@ -1457,6 +1486,7 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* setup the command */
+	g_ptr_array_add (array, g_strdup (command));
 	g_ptr_array_add (array, g_strdup ("-v"));
 
 	/* target instrument */
@@ -2236,6 +2266,9 @@ gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 	/* assume it's no longer on the window */
 	priv->already_on_window = FALSE;
 
+	/* assume it was done correctly */
+	priv->done_calibrate = TRUE;
+
 	/* set state */
 	priv->argyllcms_ok = " ";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
@@ -2677,6 +2710,7 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 	calibrate_argyll->priv->vte_previous_row = 0;
 	calibrate_argyll->priv->vte_previous_col = 0;
 	calibrate_argyll->priv->already_on_window = FALSE;
+	calibrate_argyll->priv->done_calibrate = FALSE;
 	calibrate_argyll->priv->state = GCM_CALIBRATE_ARGYLL_STATE_IDLE;
 	calibrate_argyll->priv->print = gcm_print_new ();
 	g_signal_connect (calibrate_argyll->priv->print, "status-changed",
@@ -2691,10 +2725,12 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 	/* add vte widget */
 	calibrate_argyll->priv->terminal = vte_terminal_new ();
 	vte_terminal_set_size (VTE_TERMINAL(calibrate_argyll->priv->terminal), 80, 10);
-	g_signal_connect (calibrate_argyll->priv->terminal, "child-exited",
-			  G_CALLBACK (gcm_calibrate_argyll_exit_cb), calibrate_argyll);
-	g_signal_connect (calibrate_argyll->priv->terminal, "cursor-moved",
-			  G_CALLBACK (gcm_calibrate_argyll_cursor_moved_cb), calibrate_argyll);
+	calibrate_argyll->priv->terminal_child_exited_id =
+		g_signal_connect (calibrate_argyll->priv->terminal, "child-exited",
+				G_CALLBACK (gcm_calibrate_argyll_exit_cb), calibrate_argyll);
+	calibrate_argyll->priv->terminal_cursor_moved_id =
+		g_signal_connect (calibrate_argyll->priv->terminal, "cursor-moved",
+				G_CALLBACK (gcm_calibrate_argyll_cursor_moved_cb), calibrate_argyll);
 	gcm_calibrate_dialog_pack_details (calibrate_argyll->priv->calibrate_dialog,
 					   calibrate_argyll->priv->terminal);
 }
@@ -2717,6 +2753,10 @@ gcm_calibrate_argyll_finalize (GObject *object)
 		g_main_loop_run (priv->loop);
 	}
 
+	/* disconnect */
+	g_signal_handler_disconnect (priv->terminal, priv->terminal_child_exited_id);
+	g_signal_handler_disconnect (priv->terminal, priv->terminal_cursor_moved_id);
+
 	/* hide */
 	gcm_calibrate_dialog_hide (priv->calibrate_dialog);
 
