@@ -1186,3 +1186,98 @@ gcm_cie_widget_new (void)
 	return g_object_new (GCM_TYPE_CIE_WIDGET, NULL);
 }
 
+/***************************************************************************
+ ***                          MAKE CHECK TESTS                           ***
+ ***************************************************************************/
+#ifdef EGG_TEST
+#include "egg-test.h"
+
+#include "gcm-profile.h"
+#include "gcm-xyz.h"
+
+void
+gcm_cie_widget_test (EggTest *test)
+{
+	GtkWidget *widget;
+	GtkWidget *image;
+	GtkWidget *dialog;
+	GtkWidget *vbox;
+	gboolean ret;
+	GError *error = NULL;
+	GcmProfile *profile;
+	GcmXyz *white;
+	GcmXyz *red;
+	GcmXyz *green;
+	GcmXyz *blue;
+	gint response;
+	gchar *filename_profile;
+	gchar *filename_image;
+	GFile *file = NULL;
+
+	if (!egg_test_start (test, "GcmCieWidget"))
+		return;
+
+	/************************************************************/
+	egg_test_title (test, "get a CIE widget object");
+	widget = gcm_cie_widget_new ();
+	egg_test_assert (test, widget != NULL);
+
+	/************************************************************/
+	egg_test_title (test, "get filename of image file");
+	filename_image = egg_test_get_data_file ("cie-widget.png");
+	egg_test_assert (test, (filename_image != NULL));
+
+	/************************************************************/
+	egg_test_title (test, "get filename of data file");
+	filename_profile = egg_test_get_data_file ("bluish.icc");
+	egg_test_assert (test, (filename_profile != NULL));
+
+	profile = gcm_profile_default_new ();
+	file = g_file_new_for_path (filename_profile);
+	gcm_profile_parse (profile, file, NULL);
+	g_object_get (profile,
+		      "white", &white,
+		      "red", &red,
+		      "green", &green,
+		      "blue", &blue,
+		      NULL);
+	g_object_unref (file);
+
+	g_object_set (widget,
+		      "red", red,
+		      "green", green,
+		      "blue", blue,
+		      "white", white,
+		      NULL);
+
+	/* show in a dialog as an example */
+	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "Does CIE widget match\nthe picture below?");
+	image = gtk_image_new_from_file (filename_image);
+	vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	gtk_box_pack_end (GTK_BOX(vbox), widget, TRUE, TRUE, 12);
+	gtk_box_pack_end (GTK_BOX(vbox), image, TRUE, TRUE, 12);
+	gtk_widget_set_size_request (widget, 300, 300);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
+	gtk_widget_show (widget);
+	gtk_widget_show (image);
+
+	response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	/************************************************************/
+	egg_test_title (test, "plotted as expected?");
+	egg_test_assert (test, (response == GTK_RESPONSE_YES));
+
+	gtk_widget_destroy (dialog);
+
+	g_object_unref (profile);
+	g_object_unref (white);
+	g_object_unref (red);
+	g_object_unref (green);
+	g_object_unref (blue);
+	g_free (filename_profile);
+	g_free (filename_image);
+
+	egg_test_end (test);
+}
+#endif
+
